Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1164)

Unified Diff: third_party/WebKit/Source/modules/webaudio/AudioContext.h

Issue 2103043007: Rename AbstractAudioContext to BaseAudioContext (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Use ASSERT(isGraphOwner()) instead of DCHECK Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webaudio/AudioContext.h
diff --git a/third_party/WebKit/Source/modules/webaudio/AudioContext.h b/third_party/WebKit/Source/modules/webaudio/AudioContext.h
index 33fc76846465ca12358d317e195b07e4ee893b85..1dcda97ec7e2b2d200585d3d3d91f43e49a9526d 100644
--- a/third_party/WebKit/Source/modules/webaudio/AudioContext.h
+++ b/third_party/WebKit/Source/modules/webaudio/AudioContext.h
@@ -7,7 +7,7 @@
#include "bindings/core/v8/ScriptPromise.h"
#include "bindings/core/v8/ScriptPromiseResolver.h"
-#include "modules/webaudio/AbstractAudioContext.h"
+#include "modules/webaudio/BaseAudioContext.h"
#include "platform/heap/Handle.h"
namespace blink {
@@ -16,11 +16,11 @@ class Document;
class ExceptionState;
class ScriptState;
// This is an AbstractAudioContext which actually plays sound, unlike an
// OfflineAudioContext which renders sound into a buffer.
-class AudioContext : public AbstractAudioContext {
+class AudioContext : public BaseAudioContext {
public:
- static AbstractAudioContext* create(Document&, ExceptionState&);
+ static BaseAudioContext* create(Document&, ExceptionState&);
~AudioContext() override;
DECLARE_VIRTUAL_TRACE();
@@ -16,11 +16,11 @@ class Document;
class ExceptionState;
class ScriptState;
-// This is an AbstractAudioContext which actually plays sound, unlike an
+// This is an BaseAudioContext which actually plays sound, unlike an
// OfflineAudioContext which renders sound into a buffer.

Powered by Google App Engine
This is Rietveld 408576698